# curlenetes

A small kubectl and curl wrapper to make http requests to k8s's services

How to run:
First, you need to have kubectl and curl installed.

```
uvx curlenetes namespace.service:port/path curl parameters
```
